# This file was first automatically generated by gen-acme-cpanmodules-module-from-webpage on Wed May 19 09:28:03 2021 from webpage at https://phoenixtrap.com/2021/05/18/a-list-of-perl-list-processing-modules/ by gen-acme-cpanmodules-module-from-webpage (App::CPANModulesUtils version dev).

package Acme::CPANModules::Import::MJGARDNER::ListProcessing;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-05-19'; # DATE
our $DIST = 'Acme-CPANModulesBundle-Import-MJGARDNER'; # DIST
our $VERSION = '0.002'; # VERSION

our $LIST = {
  entries => [
               { module => "List::Util" },
               { module => "List::MoreUtils" },
               { module => "List::SomeUtils" },
               { module => "List::UtilsBy" },
               { module => "List::AllUtils" },
               { module => "List::Util::MaybeXS" },
               { module => "List::MoreUtils::XS" },
               { module => "Util::Any" },
               { module => "Scalar::Util" },
               { module => "Hash::Util" },
               { module => "String::Util" },
               { module => "String::CamelCase" },
               { module => "List::Pairwise" },
               { module => "Data::Dumper" },
             ],
  summary => "List of modules mentioned in https://phoenixtrap.com/2021/05/18/a-list-of-perl-list-processing-modules/",
};

1;
# ABSTRACT: List of modules mentioned in https://phoenixtrap.com/2021/05/18/a-list-of-perl-list-processing-modules/

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::MJGARDNER::ListProcessing - List of modules mentioned in https://phoenixtrap.com/2021/05/18/a-list-of-perl-list-processing-modules/

=head1 VERSION

This document describes version 0.002 of Acme::CPANModules::Import::MJGARDNER::ListProcessing (from Perl distribution Acme-CPANModulesBundle-Import-MJGARDNER), released on 2021-05-19.

=head1 DESCRIPTION

This L<Acme::CPANModules> module was first automatically generated from list of modules mentioned at L<https://phoenixtrap.com/2021/05/18/a-list-of-perl-list-processing-modules/>.

=head1 ACME::CPANMODULES ENTRIES

=over

=item * L<List::Util>

=item * L<List::MoreUtils>

=item * L<List::SomeUtils>

=item * L<List::UtilsBy>

=item * L<List::AllUtils>

=item * L<List::Util::MaybeXS>

=item * L<List::MoreUtils::XS>

=item * L<Util::Any>

=item * L<Scalar::Util>

=item * L<Hash::Util>

=item * L<String::Util>

=item * L<String::CamelCase>

=item * L<List::Pairwise>

=item * L<Data::Dumper>

=back

=head1 FAQ

=head2 What is an Acme::CPANModules::* module?

An Acme::CPANModules::* module, like this module, contains just a list of module
names that share a common characteristics. It is a way to categorize modules and
document CPAN. See L<Acme::CPANModules> for more details.

=head2 What are ways to use this Acme::CPANModules module?

Aside from reading this Acme::CPANModules module's POD documentation, you can
install all the listed modules (entries) using L<cpanmodules> CLI (from
L<App::cpanmodules> distribution):

    % cpanmodules ls-entries Import::MJGARDNER::ListProcessing | cpanm -n

or L<Acme::CM::Get>:

    % perl -MAcme::CM::Get=Import::MJGARDNER::ListProcessing -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n

or directly:

    % perl -MAcme::CPANModules::Import::MJGARDNER::ListProcessing -E'say $_->{module} for @{ $Acme::CPANModules::Import::MJGARDNER::ListProcessing::LIST->{entries} }' | cpanm -n

This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
result for C<lcpan related-mods> command when it comes to finding related
modules for the modules listed in this Acme::CPANModules module.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-MJGARDNER>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-MJGARDNER>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-MJGARDNER/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
